Usage
"plot"(x, y, xlim = NULL, ylim = NULL, probs = NULL, main = "Shorth", xlab=NULL,
ylab=NULL,
frame.plot=TRUE,
legendpos="topright",
rug=TRUE,
rescale="neg", ...)
Arguments
x
an object of class lshorth, or a vector of x values.
y
a matrix of shorth length, if x is not of class lshorth -- not yet implemented.
probs
coverage probabilities, if x is not of class lshorth -- not yet implemented.
main
passed as argument to title.
xlab
a label for the x axis.
ylab
a label for the y axis.
frame.plot
a logical indicating whether a box should be drawn around the plot.
legendpos
position, passed to legend, or NULL for no legend.
rug
logical. If TRUE, a rug is included.
rescale
rescaling method:one of "none","neg","std","inv".
...
additional arguments passed to plot.